% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/509-extractProtCTDDClass.R
\name{extrProtCTDDClass}
\alias{extrProtCTDDClass}
\title{CTD Descriptors - Distribution (with Customized Amino Acid Classification Support)}
\usage{
extrProtCTDDClass(x, aagroup1, aagroup2, aagroup3)
}
\arguments{
\item{x}{A character vector, as the input protein sequence.}

\item{aagroup1}{A named list which contains the first group of customized
amino acid classification. See example below.}

\item{aagroup2}{A named list which contains the second group of customized
amino acid classification. See example below.}

\item{aagroup3}{A named list which contains the third group of customized
amino acid classification. See example below.}
}
\value{
A length \code{k * 15} named vector, \code{k} is the number of
amino acid properties used.
}
\description{
CTD Descriptors - Distribution (with Customized Amino Acid Classification Support)
}
\details{
This function calculates the Distribution descriptor of the
CTD descriptors, with customized amino acid classification support.
}
\note{
For this descriptor type, users need to intelligently evaluate
the underlying details of the descriptors provided, instead of using
this function with their data blindly. It would be wise to use some
negative and positive control comparisons where relevant to help guide
interpretation of the results.
}
\examples{
x = readFASTA(system.file('protseq/P00750.fasta', package = 'BioMedR'))[[1]]

# using five customized amino acid property classification
group1 = list(hydrophobicity  = c('R', 'K', 'E', 'D', 'Q', 'N'),
              normwaalsvolume = c('G', 'A', 'S', 'T', 'P', 'D', 'C'),
              polarizability  = c('G', 'A', 'S', 'D', 'T'),
              secondarystruct = c('E', 'A', 'L', 'M', 'Q', 'K', 'R', 'H'),
              solventaccess   = c('A', 'L', 'F', 'C', 'G', 'I', 'V', 'W'))

group2 = list(hydrophobicity  = c('G', 'A', 'S', 'T', 'P', 'H', 'Y'),
              normwaalsvolume = c('N', 'V', 'E', 'Q', 'I', 'L'),
              polarizability  = c('C', 'P', 'N', 'V', 'E', 'Q', 'I', 'L'),
              secondarystruct = c('V', 'I', 'Y', 'C', 'W', 'F', 'T'),
              solventaccess   = c('R', 'K', 'Q', 'E', 'N', 'D'))

group3 = list(hydrophobicity  = c('C', 'L', 'V', 'I', 'M', 'F', 'W'),
              normwaalsvolume = c('M', 'H', 'K', 'F', 'R', 'Y', 'W'),
              polarizability  = c('K', 'M', 'H', 'F', 'R', 'Y', 'W'),
              secondarystruct = c('G', 'N', 'P', 'S', 'D'),
              solventaccess   = c('M', 'S', 'P', 'T', 'H', 'Y'))

extrProtCTDDClass(x, aagroup1 = group1, aagroup2 = group2, aagroup3 = group3)
}
\references{
Inna Dubchak, Ilya Muchink, Stephen R. Holbrook and Sung-Hou Kim.
Prediction of protein folding class using global description of
amino acid sequence. \emph{Proceedings of the National Academy of Sciences}.
USA, 1995, 92, 8700-8704.

Inna Dubchak, Ilya Muchink, Christopher Mayor, Igor Dralyuk and Sung-Hou Kim.
Recognition of a Protein Fold in the Context of the SCOP classification.
\emph{Proteins: Structure, Function and Genetics}, 1999, 35, 401-407.
}
\seealso{
See \code{\link{extrProtCTDCClass}} and \code{\link{extrProtCTDTClass}}
         for Composition and Transition of the CTD descriptors with
         customized amino acid classification support.
}
\author{
Min-feng Zhu <\email{wind2zhu@163.com}>, 
        Nan Xiao <\url{http://nanx.me}>
}
\keyword{CTD}
\keyword{Composition}
\keyword{extract}
